@@ -21,7 +21,7 @@ class Tier(object):
 
     def add_point(self, point):
         """Add point (Point object) to the Tier.\nUsage:\n\t(1) You can either (a) create a Point object with \'Point()\', or (b) get a specific Point object from already existing Tiers with \'get_point()\'.\n\t(2) Pass it as the argument."""
-        point = Point(point.time, point.value, superior_PitchTier=self)
+        point = Point(point.time, point.value, superior_Tier=self)
 
         if point.time < self.start_time or point.time > self.end_time:
             raise Exception('Trying to set a point outside of time linits.')
@@ -48,7 +48,7 @@ class Tier(object):
         """Add a list (array-like) of points (Point object) to the Tier.\nUsage:\n\t(1) You can either (a) create the Point objects with \'Point()\', or (b) get specific Point objects from already existing Tiers with \'get_points()\'.\n\t(2) Pass it as the argument."""
 
         for point in points:
-            point = Point(point.time, point.value, superior_PitchTier=self)
+            point = Point(point.time, point.value, superior_Tier=self)
 
             if point.time < self.start_time or point.time > self.end_time:
                 raise Exception(
@@ -112,12 +112,12 @@ class Tier(object):
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
-        if by.by_method == 0:
+        if by == 0:
             for point in self.__points:
                 if point.time == by_target:
                     return point
 
-        elif by.by_method == 1:
+        elif by == 1:
             try:
                 point = self.__points[by_target-1]
 
@@ -125,7 +125,7 @@ class Tier(object):
             except IndexError:
                 pass
 
-        elif by.by_method == 2:
+        elif by == 2:
             for point in self.__points:
                 if point == by_target:
                     return point
@@ -138,11 +138,11 @@ class Tier(object):
 
         points = []
 
-        if by.by_method not in _by.by_methods:
+        if by not in _by.by_methods:
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
-        if by.by_method == 2:
+        if by == 2:
             for point in by_target:
                 if point in self.__points:
                     points.append(point)
@@ -151,11 +151,11 @@ class Tier(object):
                 else:
                     raise Exception('Point not found.')
 
-        elif by.by_method == 1:
+        elif by == 1:
             for index in range(by_target[0], by_target[1]+1):
                 points.append(self.get_point(index, _by.INDEX))
 
-        elif by.by_method == 0:
+        elif by == 0:
             for point in self.__points:
                 if by_target[0] <= point.time <= by_target[1]:
                     points.append(point)
@@ -165,7 +165,7 @@ class Tier(object):
     def remove_point(self, by_target, by):
         """Remove a Point object of the Tier with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
 
-        if by.by_method not in _by.by_methods:
+        if by not in _by.by_methods:
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
@@ -183,7 +183,7 @@ class Tier(object):
     def remove_points(self, by_target, by):
         """Remove Point objects of the Tier with chosen method. See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
 
-        if by.by_method not in _by.by_methods:
+        if by not in _by.by_methods:
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
@@ -199,10 +199,45 @@ class Tier(object):
         self._reindex()
         self._indexed = True
 
+    def interpolate_points(self, by_target, by, step=.01):
+        """Interpolate values between two Point objects (array-like), with given step (by default 0.01s). See \'help(by)\' for more information on the available methods. To change related parameters, use \'parameters\'."""
+
+        if by not in _by.by_methods:
+            raise Exception(
+                'Invalid by_method. Use help() to see valid methods.')
+
+        if len(by_target) != 2:
+            raise Exception(
+                '`interpolate_points()` takes exactly 2 targets.'
+            )
+
+        original_ignore_missing_point_parameter = parameters['points.ignore_missing_point']
+        parameters['points.ignore_missing_point'] = False
+        
+        points = self.get_points(by_target, by)
+        if points[0].time <= points[1]:
+            point1, point2 = points[0], points[1]
+        else:
+            point1, point2 = points[1], points[0]
+
+        self.remove_points((point1.time, point2.time), _by.TIME)
+        
+        interpolated_point_times = np.arange(point1.time, point2.time, step)[1:]
+        
+        interpolated_points = [Point(time, value, superior_Tier=self) for time, value in zip(interpolated_point_times, [point1.time, point2.time], [point1.value, point2.value])]
+        
+        self.add_points(interpolated_points, _by.POINT)
+
+        self._indexed = False
+        self._reindex()
+        self._indexed = True
+        
+        parameters['points.ignore_missing_point'] = original_ignore_missing_point_parameter
+
     def shift_point_to_time(self, target_time, by_target, by):
         """Shift Point of the Tier to chosen time with chosen method. To change related parameters, use \'parameters\'."""
 
-        if by.by_method not in _by.by_methods:
+        if by not in _by.by_methods:
             raise Exception(
                 f'Invalid by_method. Use help() to see valid methods.')
 
@@ -291,7 +326,7 @@ class Tier(object):
     def _add_point_from_file(self, point):
 
         point = Point(point.time, point.value,
-                      point.point_index, superior_PitchTier=self)
+                      point.point_index, superior_Tier=self)
 
         if point.time < self.start_time or point.time > self.end_time:
             raise Exception('Trying to set a point outside of time linits.')
@@ -378,9 +413,9 @@ class DurationTier(Tier):
 
 class Point(object):
 
-    __slots__ = ['__time', '__value', '__point_index', '__superior_PitchTier']
+    __slots__ = ['__time', '__value', '__point_index', '__superior_Tier']
 
-    def __init__(self, time, value, point_index=None, superior_PitchTier=None):
+    def __init__(self, time, value, point_index=None, superior_Tier=None):
 
         if value < 0 or np.isnan(value):
             raise Exception('Invalid value.')
@@ -393,7 +428,7 @@ class Point(object):
         self.__time = time
         self.__value = value
         self.__point_index = point_index
-        self.__superior_PitchTier = superior_PitchTier
+        self.__superior_Tier = superior_Tier
 
     @property
     def time(self):
@@ -408,8 +443,8 @@ class Point(object):
             raise Exception('Invalid time.')
         self.__time = time
 
-        if self.superior_PitchTier != None:
-            self.superior_PitchTier._reindex()
+        if self.superior_Tier != None:
+            self.superior_Tier._reindex()
 
     @property
     def value(self):
@@ -433,22 +468,22 @@ class Point(object):
     @point_index.setter
     def point_index(self, point_index):
 
-        if self.superior_PitchTier == None:
+        if self.superior_Tier == None:
             if point_index < 1:
                 raise Exception('Invalid point_index.')
             self.__point_index = point_index
 
-        elif not self.superior_PitchTier.indexed:
+        elif not self.superior_Tier.indexed:
             self.__point_index = point_index
 
         else:
             raise AttributeError('can\'t set attribute')
 
     @property
-    def superior_PitchTier(self):
+    def superior_Tier(self):
         """The PitchTier to which this Point object belongs."""
 
-        return self.__superior_PitchTier
+        return self.__superior_Tier
 
     def __repr__(self):
         return f'{self.__class__.__name__}[{self.point_index}](time={self.time}, value={self.value})'
